# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 07:52:12 2018 from module list in Acme::CPANLists::Import::PerlAdvent::2006_12_02 version 0.001.

package Acme::CPANModules::Import::PerlAdvent::2006_12_02;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [http://perladvent.org/2006/2/] (retrieved on 2016-11-07). Visit the URL for the full contents.",
  entries     => [
                   { module => "File::Find::Iterator" },
                   { module => "File::Find::Object" },
                   { module => "File::Find::Rule" },
                   { module => "File::Finder" },
                 ],
  summary     => "Modules mentioned in Perl Advent Calendar 2006 (day 2)",
};

1;
# ABSTRACT: Modules mentioned in Perl Advent Calendar 2006 (day 2)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::PerlAdvent::2006_12_02 - Modules mentioned in Perl Advent Calendar 2006 (day 2)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::PerlAdvent::2006_12_02 (from Perl distribution Acme-CPANModulesBundle-Import-PerlAdvent-2006), released on 2018-09-22.

=head1 DESCRIPTION

Modules mentioned in Perl Advent Calendar 2006 (day 2).

This list is generated by extracting module names mentioned in [http://perladvent.org/2006/2/] (retrieved on 2016-11-07). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<File::Find::Iterator>

=item * L<File::Find::Object>

=item * L<File::Find::Rule>

=item * L<File::Finder>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-PerlAdvent-2006>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-PerlAdvent-2006>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-PerlAdvent-2006>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
