# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 07:52:12 2018 from module list in Acme::CPANLists::Import::PerlAdvent::2006 version 0.001.

package Acme::CPANModules::Import::PerlAdvent::2006;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [http://perladvent.org/2006/] (retrieved on 2016-11-07). Visit the URL for the full contents.",
  entries     => [
                   { module => "Devel::FastProf" },
                   { module => "Devel::SmallProf" },
                   { module => "File::Find::Iterator" },
                   { module => "File::Find::Object" },
                   { module => "File::Find::Rule" },
                   { module => "File::Finder" },
                   { module => "Text::CSV" },
                   { module => "Treemap" },
                   { module => "XML::Simple" },
                   { module => "CGI::Minimal" },
                   { module => "CGI::Simple" },
                   { module => "HTML::Template" },
                   { module => "File::Next" },
                   { module => "Module::Starter" },
                   { module => "Acme::Don::t" },
                   { module => "File::SortedSeek" },
                   { module => "Carp" },
                   { module => "Devel::ptkdb" },
                   { module => "Fatal" },
                   { module => "Graphics::ColorNames" },
                   { module => "Shell" },
                   { module => "Shell::Autobox" },
                   { module => "IPC::Run3" },
                   { module => "File::HomeDir" },
                   { module => "Math::ErrorPropagation" },
                   { module => "Math::Symbolic" },
                   { module => "Math::Symbolic::Custom::Contains" },
                   { module => "Math::SymbolicX::Inline" },
                   { module => "Number::Uncertainty" },
                   { module => "Number::WithError" },
                   { module => "Params::Util" },
                   { module => "Test::LectroTest" },
                   { module => "prefork" },
                   { module => "Log::Dispatch::FileRotate" },
                   { module => "Logfile::Rotate" },
                   { module => "Algorithm::Diff" },
                   { module => "Text::Diff" },
                   { module => "XML::Feed" },
                   { module => "Date::Calc" },
                   { module => "Devel::Cover" },
                   { module => "Pod::Coverage" },
                   { module => "Apache::PAR" },
                   { module => "PAR::Dist" },
                   { module => "PAR::Dist::FromCPAN" },
                   { module => "PAR::Dist::InstallPPD" },
                   { module => "criticism" },
                   { module => "DBD::AnyData" },
                   { module => "DateTime::Calendar::Discordian" },
                 ],
  summary     => "Modules mentioned in Perl Advent Calendar 2006",
};

1;
# ABSTRACT: Modules mentioned in Perl Advent Calendar 2006

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::PerlAdvent::2006 - Modules mentioned in Perl Advent Calendar 2006

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::PerlAdvent::2006 (from Perl distribution Acme-CPANModulesBundle-Import-PerlAdvent-2006), released on 2018-09-22.

=head1 DESCRIPTION

Modules mentioned in Perl Advent Calendar 2006.

This list is generated by extracting module names mentioned in [http://perladvent.org/2006/] (retrieved on 2016-11-07). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<Devel::FastProf>

=item * L<Devel::SmallProf>

=item * L<File::Find::Iterator>

=item * L<File::Find::Object>

=item * L<File::Find::Rule>

=item * L<File::Finder>

=item * L<Text::CSV>

=item * L<Treemap>

=item * L<XML::Simple>

=item * L<CGI::Minimal>

=item * L<CGI::Simple>

=item * L<HTML::Template>

=item * L<File::Next>

=item * L<Module::Starter>

=item * L<Acme::Don::t>

=item * L<File::SortedSeek>

=item * L<Carp>

=item * L<Devel::ptkdb>

=item * L<Fatal>

=item * L<Graphics::ColorNames>

=item * L<Shell>

=item * L<Shell::Autobox>

=item * L<IPC::Run3>

=item * L<File::HomeDir>

=item * L<Math::ErrorPropagation>

=item * L<Math::Symbolic>

=item * L<Math::Symbolic::Custom::Contains>

=item * L<Math::SymbolicX::Inline>

=item * L<Number::Uncertainty>

=item * L<Number::WithError>

=item * L<Params::Util>

=item * L<Test::LectroTest>

=item * L<prefork>

=item * L<Log::Dispatch::FileRotate>

=item * L<Logfile::Rotate>

=item * L<Algorithm::Diff>

=item * L<Text::Diff>

=item * L<XML::Feed>

=item * L<Date::Calc>

=item * L<Devel::Cover>

=item * L<Pod::Coverage>

=item * L<Apache::PAR>

=item * L<PAR::Dist>

=item * L<PAR::Dist::FromCPAN>

=item * L<PAR::Dist::InstallPPD>

=item * L<criticism>

=item * L<DBD::AnyData>

=item * L<DateTime::Calendar::Discordian>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-PerlAdvent-2006>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-PerlAdvent-2006>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-PerlAdvent-2006>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
